@@ -64,6 +64,7 @@ public:
     ~FileCollectorPrivate();
 
     QString  filePrefix;        // default: "chapter"
+    QString  fileSuffix;        // default: ".xhtml"
     QString  pathPrefix;        // default: "OEBPS/"
 
     QList<FileCollector::FileInfo*>  m_files;  // Embedded files
@@ -71,6 +72,7 @@ public:
 
 FileCollectorPrivate::FileCollectorPrivate()
     : filePrefix("chapter")
+    , fileSuffix(".xhtml")
     , pathPrefix("OEBPS/")
 {
 }
@@ -106,6 +108,16 @@ QString FileCollector::filePrefix() const
     return d->filePrefix;
 }
 
+void FileCollector::setFileSuffix(const QString &suffix)
+{
+    d->fileSuffix = suffix;
+}
+
+QString FileCollector::fileSuffix() const
+{
+    return d->fileSuffix;
+}
+
 void FileCollector::setPathPrefix(QString prefix)
 {
     d->pathPrefix = prefix;
