@@ -41,22 +41,25 @@
 #include <qgl.h>
 #endif
 
-#include <libs/main/KoDocument.h>
+#include <KoDocument.h>
 #include <KoColorProfile.h>
+#include <KoApplication.h>
 #include <KoConfigAuthorPage.h>
+#include <KoPart.h>
 
+#include <kapplication.h>
 #include <kmessagebox.h>
 #include <kcolorbutton.h>
 #include <kcombobox.h>
 #include <kfiledialog.h>
-#include <kiconloader.h>
 #include <klineedit.h>
 #include <klocale.h>
 #include <kurlrequester.h>
 #include <kpagewidgetmodel.h>
-#include <kicon.h>
 #include <kvbox.h>
 #include <kundo2stack.h>
+
+#include <KoIcon.h>
 #include <KoConfig.h>
 
 #ifdef NEPOMUK
@@ -82,6 +85,8 @@
 
 // for the performance update
 #include <kis_cubic_curve.h>
+#include <config-ocio.h>
+
 
 GeneralTab::GeneralTab(QWidget *_parent, const char *_name)
     : WdgGeneralSettings(_parent, _name)
@@ -193,13 +198,14 @@ ColorSettingsTab::ColorSettingsTab(QWidget *parent, const char *name)
     // are shown in the profile combos
 
     QGridLayout * l = new QGridLayout(this);
-    l->setSpacing(KDialog::spacingHint());
     l->setMargin(0);
     m_page = new WdgColorSettings(this);
     l->addWidget(m_page, 0, 0);
 
     KisConfig cfg;
 
+    m_page->chkUseSystemMonitorProfile->setChecked(cfg.useSystemMonitorProfile());
+
     m_page->cmbWorkingColorSpace->setIDList(KoColorSpaceRegistry::instance()->listKeys());
     m_page->cmbWorkingColorSpace->setCurrent(cfg.workingColorSpace());
 
@@ -216,7 +222,9 @@ ColorSettingsTab::ColorSettingsTab(QWidget *parent, const char *name)
         m_page->cmbMonitorProfile->setCurrent(cfg.monitorProfile());
     if (m_page->cmbPrintProfile->contains(cfg.printerProfile()))
         m_page->cmbPrintProfile->setCurrentIndex(m_page->cmbPrintProfile->findText(cfg.printerProfile()));
+
     m_page->chkBlackpoint->setChecked(cfg.useBlackPointCompensation());
+    m_page->chkAllowLCMSOptimization->setChecked(cfg.allowLCMSOptimization());
 
     m_pasteBehaviourGroup.addButton(m_page->radioPasteWeb, PASTE_ASSUME_WEB);
     m_pasteBehaviourGroup.addButton(m_page->radioPasteMonitor, PASTE_ASSUME_MONITOR);
@@ -234,16 +242,30 @@ ColorSettingsTab::ColorSettingsTab(QWidget *parent, const char *name)
     // XXX: this needs to be available per screen!
     const KoColorProfile *profile = KisConfig::getScreenProfile();
     if (profile && profile->isSuitableForDisplay()) {
-        // We've got an X11 profile, don't allow to override
-        m_page->cmbMonitorProfile->hide();
-        m_page->lblMonitorProfile->setText(i18n("Monitor profile: ") + profile->name());
+        if (cfg.useSystemMonitorProfile()) {
+            // We've got an X11 profile, don't allow to override
+            m_page->cmbMonitorProfile->hide();
+            m_page->lblMonitorProfile->setText(i18n("Monitor profile: ") + profile->name());
+        }
     } else {
+        m_page->chkUseSystemMonitorProfile->setEnabled(false);
         m_page->cmbMonitorProfile->show();
         m_page->lblMonitorProfile->setText(i18n("&Monitor profile: "));
     }
 
     connect(m_page->cmbPrintingColorSpace, SIGNAL(activated(const KoID &)),
             this, SLOT(refillPrintProfiles(const KoID &)));
+
+#ifndef HAVE_OCIO
+    m_page->grpOcio->hide();
+#endif
+    m_page->grpOcio->setChecked(cfg.useOcio());
+    m_page->chkOcioUseEnvironment->setChecked(cfg.useOcioEnvironmentVariable());
+    enableOcioConfigPath(cfg.useOcioEnvironmentVariable());
+    m_page->txtOcioConfigPath->setText(cfg.ocioConfigurationPath());
+    connect(m_page->bnSelectOcioConfigPath, SIGNAL(clicked()), this, SLOT(selectOcioConfigPath()));
+    connect(m_page->chkOcioUseEnvironment, SIGNAL(toggled(bool)), this, SLOT(enableOcioConfigPath(bool)));
+
 }
 
 void ColorSettingsTab::setDefault()
@@ -256,8 +278,12 @@ void ColorSettingsTab::setDefault()
     refillMonitorProfiles(KoID("RGBA", ""));
 
     m_page->chkBlackpoint->setChecked(false);
+    m_page->chkAllowLCMSOptimization->setChecked(true);
     m_page->cmbMonitorIntent->setCurrentIndex(INTENT_PERCEPTUAL);
 
+    m_page->chkOcioUseEnvironment->setChecked(true);
+    m_page->txtOcioConfigPath->setText(QString());
+
     QAbstractButton *button = m_pasteBehaviourGroup.button(PASTE_ASK);
     Q_ASSERT(button);
 
@@ -305,6 +331,24 @@ void ColorSettingsTab::refillPrintProfiles(const KoID & s)
     m_page->cmbPrintProfile->setCurrent(csf->defaultProfile());
 }
 
+void ColorSettingsTab::selectOcioConfigPath()
+{
+    QString filename = m_page->txtOcioConfigPath->text();
+
+    filename = KFileDialog::getOpenFileName(QDir::cleanPath(filename), "*.ocio|OpenColorIO configuration (*.ocio)", m_page);
+    QFile f(filename);
+    if (f.exists()) {
+        m_page->txtOcioConfigPath->setText(filename);
+    }
+}
+
+void ColorSettingsTab::enableOcioConfigPath(bool enable)
+{
+    m_page->lblOcioConfig->setEnabled(!enable);
+    m_page->txtOcioConfigPath->setEnabled(!enable);
+    m_page->bnSelectOcioConfigPath->setEnabled(!enable);
+}
+
 //---------------------------------------------------------------------------------------------------
 
 void TabletSettingsTab::setDefault()
@@ -319,7 +363,6 @@ TabletSettingsTab::TabletSettingsTab(QWidget* parent, const char* name): QWidget
     setObjectName(name);
 
     QGridLayout * l = new QGridLayout(this);
-    l->setSpacing(KDialog::spacingHint());
     l->setMargin(0);
     m_page = new WdgTabletSettings(this);
     l->addWidget(m_page, 0, 0);
@@ -357,7 +400,7 @@ DisplaySettingsTab::DisplaySettingsTab(QWidget *parent, const char *name)
 {
     KisConfig cfg;
 
-    labelWarning->setPixmap(KIcon("dialog-warning").pixmap(32, 32));
+    labelWarning->setPixmap(koIcon("dialog-warning").pixmap(32, 32));
 #ifdef HAVE_OPENGL
     if (!QGLFormat::hasOpenGL()) {
         cbUseOpenGL->setEnabled(false);
@@ -572,7 +615,7 @@ KisDlgPreferences::KisDlgPreferences(QWidget* parent, const char* name)
     KVBox *vbox = new KVBox();
     KPageWidgetItem *page = new KPageWidgetItem(vbox, i18n("General"));
     page->setHeader(i18n("General"));
-    page->setIcon(KIcon(BarIcon("configure", KIconLoader::SizeMedium)));
+    page->setIcon(koIcon("configure"));
     addPage(page);
     m_general = new GeneralTab(vbox);
 
@@ -580,7 +623,7 @@ KisDlgPreferences::KisDlgPreferences(QWidget* parent, const char* name)
     vbox = new KVBox();
     page = new KPageWidgetItem(vbox, i18n("Display"));
     page->setHeader(i18n("Display"));
-    page->setIcon(KIcon("preferences-desktop-display"));
+    page->setIcon(koIcon("preferences-desktop-display"));
     addPage(page);
     m_displaySettings = new DisplaySettingsTab(vbox);
 
@@ -588,7 +631,7 @@ KisDlgPreferences::KisDlgPreferences(QWidget* parent, const char* name)
     vbox = new KVBox();
     page = new KPageWidgetItem(vbox, i18n("Color Management"));
     page->setHeader(i18n("Color"));
-    page->setIcon(KIcon("preferences-desktop-color"));
+    page->setIcon(koIcon("preferences-desktop-color"));
     addPage(page);
     m_colorSettings = new ColorSettingsTab(vbox);
 
@@ -597,7 +640,7 @@ KisDlgPreferences::KisDlgPreferences(QWidget* parent, const char* name)
     vbox = new KVBox();
     page = new KPageWidgetItem(vbox, i18n("Performance"));
     page->setHeader(i18n("Performance"));
-    page->setIcon(KIcon("preferences-system-performance"));
+    page->setIcon(koIcon("preferences-system-performance"));
     addPage(page);
     m_performanceSettings = new PerformanceTab(vbox);
 #endif
@@ -606,7 +649,7 @@ KisDlgPreferences::KisDlgPreferences(QWidget* parent, const char* name)
     vbox = new KVBox();
     page = new KPageWidgetItem(vbox, i18n("Grid"));
     page->setHeader(i18n("Grid"));
-    page->setIcon(KIcon(BarIcon("grid", KIconLoader::SizeMedium)));
+    page->setIcon(koIcon("grid"));
     addPage(page);
     m_gridSettings = new GridSettingsTab(vbox);
 
@@ -614,7 +657,7 @@ KisDlgPreferences::KisDlgPreferences(QWidget* parent, const char* name)
     vbox = new KVBox();
     page = new KPageWidgetItem(vbox, i18n("Tablet settings"));
     page->setHeader(i18n("Tablet"));
-    page->setIcon(KIcon("input-tablet"));
+    page->setIcon(koIcon("input-tablet"));
     addPage(page);
     m_tabletSettings = new TabletSettingsTab(vbox);
 
@@ -623,7 +666,7 @@ KisDlgPreferences::KisDlgPreferences(QWidget* parent, const char* name)
     vbox = new KVBox();
     page = new KPageWidgetItem(vbox, i18n("Canvas-only settings"));
     page->setHeader(i18n("Canvas-only"));
-    page->setIcon(KIcon("preferences-system-performance"));
+    page->setIcon(koIcon("preferences-system-performance"));
     addPage(page);
     m_fullscreenSettings = new FullscreenSettingsTab(vbox);
 
@@ -633,7 +676,7 @@ KisDlgPreferences::KisDlgPreferences(QWidget* parent, const char* name)
     m_authorSettings = new KoConfigAuthorPage();
     page = addPage(m_authorSettings, i18nc("@title:tab Author page", "Author"));
     page->setHeader(i18n("Author"));
-    page->setIcon(KIcon("user-identity"));
+    page->setIcon(koIcon("user-identity"));
 
 
     KisPreferenceSetRegistry *preferenceSetRegistry = KisPreferenceSetRegistry::instance();
@@ -689,7 +732,9 @@ bool KisDlgPreferences::editPreferences()
 
         cfg.setAutoSaveInterval(dialog->m_general->autoSaveInterval());
         cfg.setBackupFile(dialog->m_general->m_backupFileCheckBox->isChecked());
-        foreach(KoDocument* doc, *KoDocument::documentList()) {
+        KoApplication *app = qobject_cast<KoApplication*>(qApp);
+        foreach(KoPart* part, app->partList()) {
+            KoDocument *doc = part->document();
             doc->setAutoSave(dialog->m_general->autoSaveInterval());
             doc->setBackupFile(dialog->m_general->m_backupFileCheckBox->isChecked());
             doc->undoStack()->setUndoLimit(dialog->m_general->undoStackSize());
@@ -698,15 +743,21 @@ bool KisDlgPreferences::editPreferences()
         cfg.setZoomWithWheel(dialog->m_general->chkZoomWithWheel->isChecked());
 
         // Color settings
+        cfg.setUseSystemMonitorProfile(dialog->m_colorSettings->m_page->chkUseSystemMonitorProfile->isChecked());
         cfg.setMonitorProfile(dialog->m_colorSettings->m_page->cmbMonitorProfile->itemHighlighted());
         cfg.setWorkingColorSpace(dialog->m_colorSettings->m_page->cmbWorkingColorSpace->currentItem().id());
         cfg.setPrinterColorSpace(dialog->m_colorSettings->m_page->cmbPrintingColorSpace->currentItem().id());
         cfg.setPrinterProfile(dialog->m_colorSettings->m_page->cmbPrintProfile->itemHighlighted());
 
         cfg.setUseBlackPointCompensation(dialog->m_colorSettings->m_page->chkBlackpoint->isChecked());
+        cfg.setAllowLCMSOptimization(dialog->m_colorSettings->m_page->chkAllowLCMSOptimization->isChecked());
         cfg.setPasteBehaviour(dialog->m_colorSettings->m_pasteBehaviourGroup.checkedId());
         cfg.setRenderIntent(dialog->m_colorSettings->m_page->cmbMonitorIntent->currentIndex());
 
+        cfg.setUseOcio(dialog->m_colorSettings->m_page->grpOcio->isChecked());
+        cfg.setUseOcioEnvironmentVariable(dialog->m_colorSettings->m_page->chkOcioUseEnvironment->isChecked());
+        cfg.setOcioConfigurationPath(dialog->m_colorSettings->m_page->txtOcioConfigPath->text());
+
         // Tablet settings
         cfg.setPressureTabletCurve( dialog->m_tabletSettings->m_page->pressureCurve->curve().toString() );
 
