@@ -20,7 +20,6 @@
 #define KOINLINETEXTOBJECTMANAGER_H
 
 #include "KoInlineObject.h"
-#include "KoBookmarkManager.h"
 #include "KoVariableManager.h"
 #include "kotext_export.h"
 
@@ -138,10 +137,6 @@ public:
      * Return the variableManager.
      */
     KoVariableManager *variableManager();
-    /**
-     * Return the bookmarkManager.
-     */
-    KoBookmarkManager *bookmarkManager();
 
     /**
      * Create a list of actions that can be used to plug into a menu, for example.
@@ -187,7 +182,6 @@ private:
     QHash<int, QVariant> m_properties;
 
     KoVariableManager m_variableManager;
-    KoBookmarkManager m_bookmarkManager;
 };
 
 Q_DECLARE_METATYPE(KoInlineTextObjectManager*)
