@@ -29,6 +29,7 @@
 #include "KoTextEditor_p.h"
 #include <KoTextDocument.h>
 #include <KoInlineTextObjectManager.h>
+#include <KoTextRangeManager.h>
 #include "KoBookmark.h"
 #include <KoTextAnchor.h>
 #include <KoCanvasBase.h>
@@ -56,6 +57,10 @@ void DeleteCommand::undo()
     UndoRedoFinalizer finalizer(this);
     updateListChanges();
     m_undone = true;
+    KoTextRangeManager *rangeManager = KoTextDocument(m_document).textRangeManager();
+    foreach (KoTextRange *range, m_rangesToRemove) {
+        rangeManager->insert(range);
+    }
 }
 
 void DeleteCommand::redo()
@@ -64,6 +69,10 @@ void DeleteCommand::redo()
     if (!m_first) {
         KoTextCommandBase::redo();
         UndoRedoFinalizer finalizer(this);
+        KoTextRangeManager *rangeManager = KoTextDocument(m_document).textRangeManager();
+        foreach (KoTextRange *range, m_rangesToRemove) {
+            rangeManager->remove(range);
+        }
     } else {
         m_first = false;
         if (m_document) {
@@ -129,7 +138,6 @@ void DeleteCommand::doDelete()
     Q_ASSERT(textEditor);
     QTextCursor *caret = textEditor->cursor();
     QTextCharFormat charFormat = caret->charFormat();
-    KoInlineTextObjectManager *inlineObjectManager = KoTextDocument(m_document).inlineTextObjectManager();
 
     if (!textEditor->hasSelection()) {
         if (m_mode == PreviousChar) {
@@ -145,10 +153,14 @@ void DeleteCommand::doDelete()
 
     foreach (KoInlineObject *object, m_invalidInlineObjects) {
         deleteTextAnchor(object);
-        deleteBookmark(object);
     }
-    foreach (KoInlineObject *object, m_bookmarksToRemove) {
-        inlineObjectManager->removeInlineObject(object); // doesn't remove the character
+
+    KoTextRangeManager *rangeManager = KoTextDocument(m_document).textRangeManager();
+
+    m_rangesToRemove = rangeManager->textRangesChangingWithin(textEditor->selectionStart(), textEditor->selectionEnd(), textEditor->selectionStart(), textEditor->selectionEnd());
+
+    foreach (KoTextRange *range, m_rangesToRemove) {
+        rangeManager->remove(range);
     }
 
     if (textEditor->hasComplexSelection()) {
@@ -164,68 +176,9 @@ void DeleteCommand::doDelete()
 
     caret->deleteChar();
 
-    restoreUnmatchedBookmarks(textEditor);
-
     caret->setCharFormat(charFormat);
 }
 
-void DeleteCommand::deleteBookmark(KoInlineObject *object)
-{
-    KoBookmark *bookmark = dynamic_cast<KoBookmark*>(object);
-    if (bookmark) {
-        KoInlineTextObjectManager *inlineObjectManager = KoTextDocument(m_document).inlineTextObjectManager();
-        KoBookmarkManager *bookmarkManager = inlineObjectManager->bookmarkManager();
-
-        KoBookmark::BookmarkType type = bookmark->type();
-        if (type == KoBookmark::StartBookmark) {
-            KoBookmark *endmark = bookmark->endBookmark();
-            Q_ASSERT(endmark);
-            if (endmark && !m_invalidInlineObjects.contains(endmark)) {
-                m_unmatchedBookmarks << bookmark;
-            } else {
-                //don't remove it yet as we need to find it below
-                m_bookmarksToRemove << bookmark;
-            }
-        } else if (type == KoBookmark::EndBookmark) {
-            KoBookmark *startmark = bookmarkManager->retrieveBookmark(bookmark->name());
-            Q_ASSERT(startmark);
-            if (startmark && !m_invalidInlineObjects.contains(startmark)) {
-                m_unmatchedBookmarks << bookmark;
-            } else {
-                inlineObjectManager->removeInlineObject(object); // doesn't remove the character
-            }
-        } else {
-            // single bookmark - can be removed right away
-            inlineObjectManager->removeInlineObject(object); // doesn't remove the character
-        }
-        // Note: Don't delete the object. Removed objects are stored by the bookmark manager
-        // for future use. Also, start bookmarks might still have a reference to the end bookmark
-        // that is being removed.
-    }
-}
-
-void DeleteCommand::restoreUnmatchedBookmarks(KoTextEditor *editor)
-{
-    QTextCursor *caret = editor->cursor();
-    int currentPosition = caret->position();
-
-    // now restore the bookmarks that spanned beyond the selection we removed
-    foreach(KoBookmark *bookmark, m_unmatchedBookmarks) {
-
-        QTextCharFormat oldCf = editor->charFormat();
-        // create a new format out of the old so that the current formatting is
-        // also used for the inserted object.  KoVariables render text too ;)
-        QTextCharFormat cf(oldCf);
-        cf.setObjectType(QTextFormat::UserObject + 1);
-        cf.setProperty(KoInlineTextObjectManager::InlineInstanceId, bookmark->id());
-        caret->insertText(QString(QChar::ObjectReplacementCharacter), cf);
-        // reset to use old format so that the InlineInstanceId is no longer set.
-        caret->setCharFormat(oldCf);
-    }
-
-    editor->updateInlineObjectPosition(currentPosition);
-}
-
 void DeleteCommand::deleteTextAnchor(KoInlineObject *object)
 {
     if (object) {
