@@ -22,8 +22,9 @@
 #include "KoView.h"
 
 // local directory
-
 #include "KoView_p.h"
+
+#include "KoPart.h"
 #include "KoDockRegistry.h"
 #include "KoDocument.h"
 #include "KoMainWindow.h"
@@ -34,9 +35,10 @@
 #include "KoPageLayout.h"
 #include "KoPrintJob.h"
 
+#include <KoIcon.h>
+
 #include <kactioncollection.h>
 #include <kglobalsettings.h>
-#include <kicon.h>
 #include <klocale.h>
 #include <kparts/partmanager.h>
 #include <kparts/event.h>
@@ -83,6 +85,7 @@ public:
     }
 
     QPointer<KoDocument> document; // our KoDocument
+    KoPart *part; // our part
     QPointer<KParts::PartManager> manager;
     QWidget *tempActiveWidget;
     bool registered;  // are we registered at the part manager?
@@ -156,11 +159,12 @@ public:
     QToolBar* viewBar;
 };
 
-KoView::KoView(KoDocument *document, QWidget *parent)
+KoView::KoView(KoPart *part, KoDocument *document, QWidget *parent)
         : QWidget(parent)
         , d(new KoViewPrivate)
 {
     Q_ASSERT(document);
+    Q_ASSERT(part);
 
     setObjectName(newObjectName());
 
@@ -169,6 +173,8 @@ KoView::KoView(KoDocument *document, QWidget *parent)
 
     //kDebug(30003) <<"KoView::KoView" << this;
     d->document = document;
+    d->part = part;
+
     KParts::PartBase::setPartObject(this);
 
     setFocusPolicy(Qt::StrongFocus);
@@ -182,7 +188,6 @@ KoView::KoView(KoDocument *document, QWidget *parent)
         connect(d->document, SIGNAL(clearStatusBarMessage()),
                 this, SLOT(slotClearStatusText()));
     }
-    d->document->setCurrent();
 
     d->scrollTimer = new QTimer(this);
     connect(d->scrollTimer, SIGNAL(timeout()), this, SLOT(slotAutoScroll()));
@@ -204,11 +209,10 @@ KoView::~KoView()
     kDebug(30003) << "KoView::~KoView" << this;
     delete d->scrollTimer;
     if (!d->documentDeleted) {
-        if (koDocument()) {
+        if (d->document) {
             if (d->manager && d->registered)   // if we aren't registered we mustn't unregister :)
-                d->manager->removePart(koDocument());
-            d->document->removeView(this);
-            d->document->setCurrent(false);
+                d->manager->removePart(d->part);
+            d->part->removeView(this);
         }
     }
     delete d;
@@ -286,9 +290,9 @@ bool KoView::documentDeleted() const
 void KoView::setPartManager(KParts::PartManager *manager)
 {
     d->manager = manager;
-    if (!manager->parts().contains(koDocument())) {  // is there another view registered?
+    if (!manager->parts().contains(d->part)) {  // is there another view registered?
         d->registered = true; // no, so we have to register now and ungregister again in the DTOR
-        manager->addPart(koDocument(), false);
+        manager->addPart(d->part, false);
     } else
         d->registered = false;  // There is already another view registered for that part...
 }
@@ -306,7 +310,7 @@ QAction *KoView::action(const QDomElement &element) const
     QAction *act = KXMLGUIClient::action(name.toUtf8());
 
     if (!act)
-        act = d->document->KXMLGUIClient::action(name.toUtf8());
+        act = d->part->KXMLGUIClient::action(name.toUtf8());
 
     // last resort, try to get action from the main window if there is one
     if (!act && shell())
@@ -320,7 +324,7 @@ QAction *KoView::action(const char* name) const
     QAction *act = KXMLGUIClient::action(name);
 
     if (!act)
-        act = d->document->KXMLGUIClient::action(name);
+        act = d->part->KXMLGUIClient::action(name);
 
     // last resort, try to get action from the main window if there is one
     if (!act && shell())
@@ -332,7 +336,7 @@ QAction *KoView::action(const char* name) const
 KoDocument *KoView::hitTest(const QPoint &viewPos)
 {
     Q_UNUSED(viewPos);
-    return koDocument(); // we no longer have child documents
+    return d->document; // we no longer have child documents
 }
 
 int KoView::leftBorder() const
@@ -518,14 +522,14 @@ QPrintDialog *KoView::createPrintDialog(KoPrintJob *printJob, QWidget *parent)
 
 void KoView::setupGlobalActions()
 {
-    KAction *actionNewView  = new KAction(KIcon("window-new"), i18n("&New View"), this);
+    KAction *actionNewView  = new KAction(koIcon("window-new"), i18n("&New View"), this);
     actionCollection()->addAction("view_newview", actionNewView);
     connect(actionNewView, SIGNAL(triggered(bool)), this, SLOT(newView()));
 
     actionCollection()->addAction("edit_undo", new KoUndoStackAction(d->document->undoStack(), KoUndoStackAction::UNDO));
     actionCollection()->addAction("edit_redo", new KoUndoStackAction(d->document->undoStack(), KoUndoStackAction::RED0));
 
-    KSelectAction *actionAuthor  = new KSelectAction(KIcon("user-identity"), i18n("Active Author Profile"), this);
+    KSelectAction *actionAuthor  = new KSelectAction(koIcon("user-identity"), i18n("Active Author Profile"), this);
     actionAuthor->addAction(i18n("Default Author Profile"));
     actionAuthor->addAction(i18nc("choice for author profile", "Anonymous"));
     KConfig *config = KoGlobal::calligraConfig();
@@ -552,11 +556,11 @@ void KoView::setupGlobalActions()
 
 void KoView::newView()
 {
-    Q_ASSERT((d != 0 && d->document));
+    Q_ASSERT((d != 0 && d->document && d->part));
 
     KoDocument *thisDocument = d->document;
-    KoMainWindow *shell = new KoMainWindow(thisDocument->componentData());
-    shell->setRootDocument(thisDocument);
+    KoMainWindow *shell = new KoMainWindow(d->part->componentData());
+    shell->setRootDocument(thisDocument, d->part);
     shell->show();
 }
 
