@@ -871,7 +871,7 @@ void KoTextLayoutTableArea::paint(QPainter *painter, const KoTextDocumentLayout:
                 if (bgBrush != Qt::NoBrush) {
                     cellContext.background = bgBrush.color();
                 }
-                paintCell(painter, cellContext, tableCell);
+                paintCell(painter, cellContext, tableCell, d->cellAreas[testRow][column]);
             }
         }
     }
@@ -882,7 +882,7 @@ void KoTextLayoutTableArea::paint(QPainter *painter, const KoTextDocumentLayout:
 
     bool hasAntialiasing = painter->testRenderHint(QPainter::Antialiasing);
 
-    // Draw header row cell backgrounds and contents AND borders.
+    // Draw header row cell backgrounds and contents.
     for (int row = 0; row < d->headerRows; ++row) {
         for (int column = 0; column < d->table->columns(); ++column) {
             QTextTableCell tableCell = d->table->cellAt(row, column);
@@ -894,8 +894,17 @@ void KoTextLayoutTableArea::paint(QPainter *painter, const KoTextDocumentLayout:
                 if (bgBrush != Qt::NoBrush) {
                     cellContext.background = bgBrush.color();
                 }
-                paintCell(painter, cellContext, tableCell);
+                paintCell(painter, cellContext, tableCell, d->cellAreas[testRow][column]);
+            }
+        }
+    }
+    // Draw header row cell borders.(need to be second step so nabour cells don't overwrite)
+    for (int row = 0; row < d->headerRows; ++row) {
+        for (int column = 0; column < d->table->columns(); ++column) {
+            QTextTableCell tableCell = d->table->cellAt(row, column);
 
+            int testRow = row == firstRow ? tableCell.row() : row;
+            if (d->cellAreas[testRow][column]) {
                 painter->setRenderHint(QPainter::Antialiasing, true);
                 paintCellBorders(painter, context, tableCell, false, &accuBlankBorders);
                 painter->setRenderHint(QPainter::Antialiasing, hasAntialiasing);
@@ -933,7 +942,7 @@ void KoTextLayoutTableArea::paint(QPainter *painter, const KoTextDocumentLayout:
     }
 }
 
-void KoTextLayoutTableArea::paintCell(QPainter *painter, const KoTextDocumentLayout::PaintContext &context, QTextTableCell tableCell)
+void KoTextLayoutTableArea::paintCell(QPainter *painter, const KoTextDocumentLayout::PaintContext &context, QTextTableCell tableCell, KoTextLayoutArea *frameArea)
 {
     int row = tableCell.row();
     int column = tableCell.column();
@@ -977,7 +986,7 @@ void KoTextLayoutTableArea::paintCell(QPainter *painter, const KoTextDocumentLay
     }
 
     // Paint the content of the cellArea
-    d->cellAreas[row][column]->paint(painter, context);
+    frameArea->paint(painter, context);
 
     painter->restore();
 }
