@@ -29,22 +29,28 @@
 #include <KoView.h>
 #include <KoPrintingDialog.h>
 #include <KoPageLayout.h>
+#include <KoDockFactoryBase.h>
 
 #include <QMap>
 #include <QTreeView>
 #include <QSplitter>
 #include <QList>
 #include <QPointer>
+#include <QDockWidget>
 
 class KAction;
+class KToggleAction;
 
 class QWidget;
 class QMetaEnum;
 class QAbstractItemModel;
+class QDockWidget;
+class QMainWindow;
 
 class KoDocument;
 class KoPrintJob;
-class KoPageLayoutWidget;
+struct KoPageLayoutWidget;
+class KoPart;
 
 /// The main namespace
 namespace KPlato
@@ -62,6 +68,35 @@ class ViewBase;
 class TreeViewBase;
 class DoubleTreeViewBase;
 
+class DockWidget;
+
+//------------------
+
+class KPLATOUI_EXPORT DockWidget : public QDockWidget
+{
+    Q_OBJECT
+public:
+    DockWidget( ViewBase *v, const QString &identity, const QString &title );
+
+    void activate( KoMainWindow *shell );
+    void deactivate( KoMainWindow *shell );
+    bool shown() const;
+
+    bool saveXml( QDomElement &context ) const;
+    void loadXml( const KoXmlElement &context );
+
+    const ViewBase *view;        /// The view this docker belongs to
+    QString id;                  /// Docker identity
+    Qt::DockWidgetArea location; /// The area the docker should go when visible
+    bool editor;                 /// Editor dockers will not be shown in read only mode
+
+public slots:
+    void setShown( bool show );
+    void setLocation( Qt::DockWidgetArea area );
+
+private:
+    bool m_shown;                /// The dockers visivbility when the view is active
+};
 
 //------------------
 class KPLATOUI_EXPORT PrintingOptions
@@ -133,15 +168,17 @@ public:
     void paintHeaderFooter( QPainter &p, const PrintingOptions &options, int pageNumber, const Project &project );
     
     PrintingOptions printingOptions() const;
-    void setPrintingOptions( const PrintingOptions &opt);
     
     QWidget *createPageLayoutWidget() const;
     QAbstractPrintDialog::PrintDialogOptions printDialogOptions() const;
 
 signals:
     void changed( const PrintingOptions &opt );
+    void changed();
     
 public slots:
+    void setPrintingOptions( const PrintingOptions &opt);
+    void setPrinterPageLayout( const KoPageLayout &pagelayout );
     virtual void startPrinting(RemovePolicy removePolicy = DoNotDelete);
 
 protected:
@@ -149,11 +186,11 @@ protected:
     int headerFooterHeight( const PrintingOptions::Data &options ) const;
     void drawBottomRect( QPainter &p, const QRect &r );
 
-    void setPrinterPageLayout();
 
 protected:
     ViewBase *m_view;
     PrintingHeaderFooter *m_widget;
+    int m_textheight;
 };
 
 class KPLATOUI_EXPORT ViewActionLists
@@ -198,7 +235,7 @@ class KPLATOUI_EXPORT ViewBase : public KoView, public ViewActionLists
     Q_OBJECT
 public:
     /// Contructor
-    ViewBase(KoDocument *doc, QWidget *parent);
+    ViewBase(KoPart *part, KoDocument *doc, QWidget *parent);
     /// Destructor
     virtual ~ViewBase();
     /// Return the part (document) this view handles
@@ -214,7 +251,7 @@ public:
     bool isActive() const;
     
     /// Set the project this view shall handle.
-    virtual void setProject( Project *project ) { m_proj = project; }
+    virtual void setProject( Project *project );
     /// Return the project
     virtual Project *project() const { return m_proj; }
     /// Draw data from current part / project
@@ -247,9 +284,15 @@ public:
 
     virtual KoPrintJob *createPrintJob();
     PrintingOptions printingOptions() const { return m_printingOptions; }
-    
+    static QWidget *createPageLayoutWidget( ViewBase *view );
+    static PrintingHeaderFooter *createHeaderFooterWidget( ViewBase *view );
     void addAction( const QString list, QAction *action ) { ViewActionLists::addAction( list, action );  }
 
+    virtual void createDockers() {}
+    void addDocker( DockWidget *ds );
+    QList<DockWidget*> dockers() const;
+    DockWidget *findDocker( const QString &id ) const;
+
 public slots:
     void setPrintingOptions( const PrintingOptions &opt ) { m_printingOptions = opt; }
     /// Activate/deactivate the gui
@@ -274,6 +317,9 @@ signals:
     /// Emitted when options are modified
     void optionsModified();
 
+    void projectChanged( Project *project );
+    void readWriteChanged( bool );
+
 protected slots:
     virtual void slotOptions() {}
     virtual void slotOptionsFinished( int result );
@@ -288,6 +334,8 @@ protected:
     ScheduleManager *m_schedulemanager;
     
     KoPageLayout m_pagelayout;
+
+    QList<DockWidget*> m_dockers;
 };
 
 //------------------
@@ -408,7 +456,7 @@ protected:
     void contextMenuEvent ( QContextMenuEvent * event );
 
     void dragMoveEvent(QDragMoveEvent *event);
-
+    void dropEvent( QDropEvent *e );
     void updateSelection( const QModelIndex &oldidx, const QModelIndex &newidx, QKeyEvent *event );
 
 protected slots:
@@ -493,6 +541,7 @@ public:
     void setAcceptDropsOnView( bool );
     void setDropIndicatorShown( bool );
     void setDragDropMode( QAbstractItemView::DragDropMode mode );
+    void setDragDropOverwriteMode( bool mode );
     void setDragEnabled ( bool mode );
     void setDefaultDropAction( Qt::DropAction action );
 
@@ -585,7 +634,7 @@ protected slots:
 protected:
     void init();
     QList<int> expandColumnList( const QList<int> lst ) const;
-    
+
 protected:
     TreeViewBase *m_leftview;
     TreeViewBase *m_rightview;
