@@ -46,8 +46,8 @@ using namespace Calligra::Sheets;
 // gdb or from debug output to check that everything is set up ok.
 void DependencyManager::Private::dump() const
 {
-    QMap<Cell, Region>::ConstIterator mend(providers.end());
-    for (QMap<Cell, Region>::ConstIterator mit(providers.begin()); mit != mend; ++mit) {
+    QHash<Cell, Region>::ConstIterator mend(providers.end());
+    for (QHash<Cell, Region>::ConstIterator mit(providers.begin()); mit != mend; ++mit) {
         Cell cell = mit.key();
 
         QStringList debugStr;
@@ -60,11 +60,12 @@ void DependencyManager::Private::dump() const
     }
 
     foreach(Sheet* sheet, consumers.keys()) {
-        const QList< QPair<QRectF, Cell> > pairs = consumers[sheet]->intersectingPairs(QRect(1, 1, KS_colMax, KS_rowMax)).values();
+        QList<QRectF> keys = consumers[sheet]->keys();
+        QList<Cell> values = consumers[sheet]->values();
         QHash<QString, QString> table;
-        for (int i = 0; i < pairs.count(); ++i) {
-            Region tmpRange(pairs[i].first.toRect(), sheet);
-            table.insertMulti(tmpRange.name(), pairs[i].second.name());
+        for (int i = 0; i < keys.count(); ++i) {
+            Region tmpRange(keys[i].toRect(), sheet);
+            table.insertMulti(tmpRange.name(), values[i].name());
         }
         foreach(QString uniqueKey, table.uniqueKeys()) {
             QStringList debugStr(table.values(uniqueKey));
@@ -189,6 +190,7 @@ void DependencyManager::updateAllDependencies(const Map* map, KoUpdater *updater
     d->depths.clear();
 
     int cellsCount = 9;
+    int cellCurrent = 0;
 
     if (updater) {
         updater->setProgress(0);
@@ -198,31 +200,20 @@ void DependencyManager::updateAllDependencies(const Map* map, KoUpdater *updater
     }
 
     Cell cell;
-    int cellCurrent = 0;
     foreach(const Sheet* sheet, map->sheetList()) {
         for (int c = 0; c < sheet->formulaStorage()->count(); ++c, ++cellCurrent) {
             cell = Cell(sheet, sheet->formulaStorage()->col(c), sheet->formulaStorage()->row(c));
 
             d->generateDependencies(cell, sheet->formulaStorage()->data(c));
-            if (!sheet->formulaStorage()->data(c).isValid())
-                cell.setValue(Value::errorPARSE());
-
-            if (updater)
-                updater->setProgress(int(qreal(cellCurrent) / qreal(cellsCount) * 50.));
-        }
-    }
-    cellCurrent = 0;
-    foreach(const Sheet* sheet, map->sheetList()) {
-        for (int c = 0; c < sheet->formulaStorage()->count(); ++c, ++cellCurrent) {
-            cell = Cell(sheet, sheet->formulaStorage()->col(c), sheet->formulaStorage()->row(c));
-
             if (!d->depths.contains(cell)) {
                 int depth = d->computeDepth(cell);
                 d->depths.insert(cell , depth);
             }
+            if (!sheet->formulaStorage()->data(c).isValid())
+                cell.setValue(Value::errorPARSE());
 
             if (updater)
-                updater->setProgress(50 + int(qreal(cellCurrent) / qreal(cellsCount) * 50.));
+                updater->setProgress(int(qreal(cellCurrent) / qreal(cellsCount) * 100.));
         }
     }
 
@@ -438,13 +429,33 @@ void DependencyManager::Private::generateDepths(const Region& region)
 
         int bottom = range.bottom();
         if (bottom > cells->rows()) bottom = cells->rows();
-        int right = range.right();
-        if (right > cells->columns()) right = cells->columns();
 
         for (int row = range.top(); row <= bottom; ++row) {
-            for (int col = range.left(); col <= right; ++col) {
+            int col = 0;
+            Formula formula = sheet->formulaStorage()->firstInRow(row, &col);
+            if (col > 0 && col < range.left())
+                formula = sheet->formulaStorage()->nextInRow(col, row, &col);
+            while (col != 0 && col <= range.right()) {
                 Cell cell(sheet, col, row);
-                generateDepths(cell, computedDepths);
+
+                // compute the cell depth and automatically the depths of its providers
+                int depth = computeDepth(cell);
+                depths.insert(cell, depth);
+
+                // compute the consumers' depths
+                QHash<Sheet*, RTree<Cell>*>::ConstIterator cit = consumers.constFind(cell.sheet());
+                if (cit == consumers.constEnd()) {
+                    formula = sheet->formulaStorage()->nextInRow(col, row, &col);
+                    continue;
+                }
+
+                const QList<Cell> consumers = cit.value()->contains(cell.cellPosition());
+                foreach (const Cell &c, consumers) {
+                    if (!region.contains(c.cellPosition(), c.sheet()))
+                        generateDepths(c, computedDepths);
+                }
+
+                formula = sheet->formulaStorage()->nextInRow(col, row, &col);
             }
         }
     }
@@ -599,8 +610,8 @@ void DependencyManager::Private::computeDependencies(const Cell& cell, const For
                     Sheet* sheet = region.firstSheet();
 
                     // create consumer tree, if not existing yet
-                    QHash<Sheet*, RTree<Cell>*>::ConstIterator it = consumers.constFind(sheet);
-                    if (it == consumers.constEnd()) {
+                    QHash<Sheet*, RTree<Cell>*>::iterator it = consumers.find(sheet);
+                    if (it == consumers.end()) {
                         it = consumers.insert(sheet, new RTree<Cell>());
                     }
                     // add cell as consumer of the range
